aboutsummaryrefslogtreecommitdiff
path: root/src/guile/skribilo/package/eq.scm
diff options
context:
space:
mode:
Diffstat (limited to 'src/guile/skribilo/package/eq.scm')
-rw-r--r--src/guile/skribilo/package/eq.scm7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/guile/skribilo/package/eq.scm b/src/guile/skribilo/package/eq.scm
index 31b297d..a9a64c1 100644
--- a/src/guile/skribilo/package/eq.scm
+++ b/src/guile/skribilo/package/eq.scm
@@ -60,9 +60,10 @@
;; native engine.
(make-parameter #f))
-(define-public *use-lout-eq2?*
- ;; Whether the use the new Lout `eq2' package instead of `eq'.
- (make-parameter #f))
+(define-public *use-lout-math?*
+ ;; Whether the use the Lout's `math' package (new in Lout 3.36) instead
+ ;; of `eq'.
+ (make-parameter #t))
(define %operators